@@ -1,10 +1,14 @@
 import numpy as np
 import pandas as pd
 from assertpy import assert_that
-try:
-    from sklearn.metrics import roc_curve as sklearn_roc_curve
-except ImportError:
-    raise ImportError("sklearn package is required")
+
+from deepdriver.sdk.lib.lazyloader import LazyLoader
+sklearn_matric = LazyLoader('deepdriver.metrics.roc_curve', globals(), 'sklearn.metrics')  #layzyload
+#
+# try:
+#     from sklearn.metrics import roc_curve as sklearn_roc_curve
+# except ImportError:
+#     raise ImportError("sklearn package is required")
 
 from deepdriver.sdk.chart.chart import Chart, TYPE_ROC_CURVE
 
@@ -30,7 +34,7 @@ def roc_curve(y_true: list, probs: list, class_names: list = None, title: str =
         else:
             class_label = classes[i]
 
-        fpr[class_label], tpr[class_label], _ = sklearn_roc_curve(
+        fpr[class_label], tpr[class_label], _ = sklearn_matric.roc_curve(
             y_true, y_probas[..., i], pos_label=classes[i]
         )
 
