@@ -144,7 +144,7 @@ def run_hpo(exp_name: str = "", team_name: str = "", remote: bool = False, hpo_c
 def prepare_dataset(dataset: dict = None) -> Tuple[bool, str]:
     assert_that(dataset).is_not_none()
 
-    arti = deepdriver.get_artifact(**dataset)
+    arti = deepdriver.get_artifact(**{key:dataset[key] for key in dataset.keys() if key in ['name', 'type', 'tag', 'team_name', 'exp_name']})
     if arti.entry_list == []:
         logger.error(f"artifat(name={dataset['name']}, type={dataset['type']}) have no entries")
         return False, None
@@ -157,7 +157,7 @@ def prepare_dataset(dataset: dict = None) -> Tuple[bool, str]:
 def prepare_code(code: dict = None) -> Tuple[bool, str, Callable]:
     assert_that(code).is_not_none()
 
-    arti = deepdriver.get_artifact(name=code['name'], type=code['type'])
+    arti = deepdriver.get_artifact(**{key:code[key] for key in code.keys() if key in ['name', 'type', 'tag', 'team_name', 'exp_name']})
     if arti.entry_list == []:
         return False, None, None
     else:
